@@ -1,7 +1,8 @@
 # set logger handler
 import logging
 import os
-from .info import (__version__, __packagename__)
+from .info import __packagename__
+from ._version import __version__
 
 # Rudimentary logging support.
 lgr = logging.getLogger(__name__)
