@@ -1,7 +1,9 @@
 # TODO: break this up by modules
+import logging
 
 from heudiconv.cli.run import main as runner
-from heudiconv.main import workflow
+from heudiconv.main import (workflow,
+                            process_extra_commands)
 from heudiconv import __version__
 from heudiconv.utils import (create_file_if_missing,
                              load_json,
@@ -303,3 +305,56 @@ def test_no_etelemetry():
     with patch.dict('sys.modules', {'etelemetry': None}):
         workflow(outdir='/dev/null', command='ls',
                  heuristic='reproin', files=[])
+
+
+# Test two scenarios:
+# -study without sessions
+# -study with sessions
+# The "expected_folder" is the session folder without the tmpdir
+@pytest.mark.parametrize(
+    "session, expected_folder", [
+        ('', 'foo/sub-{sID}'),
+        ('pre', 'foo/sub-{sID}/ses-pre')
+    ]
+)
+def test_populate_intended_for(tmpdir, session, expected_folder, caplog):
+    """
+    Tests for "process_extra_commands" when the command is
+    'populate-intended-for'
+    """
+    # Because the function .utils.populate_intended_for already has its own
+    # tests, here we just test that "process_extra_commands", when 'command'
+    # is 'populate_intended_for' does what we expect (loop through the list of
+    # subjects and calls 'populate_intended_for' using the 'POPULATE_INTENDED_FOR_OPTS'
+    # defined in the heuristic file 'example.py'). We call it using folders
+    # that don't exist, and check that the output is the expected.
+    bids_folder = expected_folder.split('sub-')[0]
+    subjects = ['1', '2']
+    caplog.set_level(logging.INFO)
+    process_extra_commands(bids_folder, 'populate-intended-for', [], '',
+                           'example', session, subjects, None)
+    for s in subjects:
+        expected_info = 'Adding "IntendedFor" to the fieldmaps in ' + expected_folder.format(sID=s)
+        assert any(expected_info in co.message for co in caplog.records)
+
+    # try the same, but without specifying the subjects or the session.
+    # the code in main should find any subject in the output folder and call
+    # populate_intended_for on each of them (or for each of the sessions, if
+    # the data for that subject is organized in sessions):
+    # TODO: Add a 'participants.tsv' file with one of the subjects missing;
+    #  the 'process_extra_commands' call should print out a warning
+    caplog.clear()
+    outdir = opj(str(tmpdir), bids_folder)
+    for subj in subjects:
+        subj_dir = opj(outdir, 'sub-' + subj)
+        print('Creating output dir: %s', subj_dir)
+        os.makedirs(subj_dir)
+        if session:
+            os.makedirs(opj(subj_dir, 'ses-' + session))
+    process_extra_commands(outdir, 'populate-intended-for', [], '',
+                           'example', [], [], None)
+    for s in subjects:
+        expected_info = 'Adding "IntendedFor" to the fieldmaps in ' + opj(str(tmpdir), expected_folder.format(sID=s))
+        assert any(expected_info in co.message for co in caplog.records)
+
+
